# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/image_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/image_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$fsai_grpc_api/protos/image_api.proto\x1a fsai_grpc_api/protos/utils.proto\"c\n\x18\x46indOrCreateImageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x1a\n\x08geo_bbox\x18\x04 \x01(\x0b\x32\x08.GeoBbox\"I\n\x19\x46indOrCreateImageResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x03\"\x1d\n\x0fGetImageRequest\x12\n\n\x02id\x18\x01 \x01(\x03\"\x87\x01\n\x13ImageObjectResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x0f\n\x07min_lat\x18\x03 \x01(\x02\x12\x0f\n\x07max_lat\x18\x04 \x01(\x02\x12\x0f\n\x07min_lon\x18\x05 \x01(\x02\x12\x0f\n\x07max_lon\x18\x06 \x01(\x02\"!\n\nImageBytes\x12\x13\n\x0bimage_bytes\x18\x01 \x01(\x0c\x32\xbd\x01\n\x08ImageApi\x12J\n\x11\x46indOrCreateImage\x12\x19.FindOrCreateImageRequest\x1a\x1a.FindOrCreateImageResponse\x12\x32\n\x08GetImage\x12\x10.GetImageRequest\x1a\x14.ImageObjectResponse\x12\x31\n\x0eGetImageStream\x12\x10.GetImageRequest\x1a\x0b.ImageBytes0\x01\x62\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_FINDORCREATEIMAGEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateImageRequest',
  full_name='FindOrCreateImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FindOrCreateImageRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='FindOrCreateImageRequest.width', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='FindOrCreateImageRequest.height', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='FindOrCreateImageRequest.geo_bbox', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=173,
)


_FINDORCREATEIMAGERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateImageResponse',
  full_name='FindOrCreateImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateImageResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='FindOrCreateImageResponse.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=248,
)


_GETIMAGEREQUEST = _descriptor.Descriptor(
  name='GetImageRequest',
  full_name='GetImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='GetImageRequest.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=279,
)


_IMAGEOBJECTRESPONSE = _descriptor.Descriptor(
  name='ImageObjectResponse',
  full_name='ImageObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ImageObjectResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ImageObjectResponse.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lat', full_name='ImageObjectResponse.min_lat', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lat', full_name='ImageObjectResponse.max_lat', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lon', full_name='ImageObjectResponse.min_lon', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lon', full_name='ImageObjectResponse.max_lon', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=417,
)


_IMAGEBYTES = _descriptor.Descriptor(
  name='ImageBytes',
  full_name='ImageBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_bytes', full_name='ImageBytes.image_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=452,
)

_FINDORCREATEIMAGEREQUEST.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_FINDORCREATEIMAGERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_IMAGEOBJECTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['FindOrCreateImageRequest'] = _FINDORCREATEIMAGEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateImageResponse'] = _FINDORCREATEIMAGERESPONSE
DESCRIPTOR.message_types_by_name['GetImageRequest'] = _GETIMAGEREQUEST
DESCRIPTOR.message_types_by_name['ImageObjectResponse'] = _IMAGEOBJECTRESPONSE
DESCRIPTOR.message_types_by_name['ImageBytes'] = _IMAGEBYTES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FindOrCreateImageRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEIMAGEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateImageRequest)
  })
_sym_db.RegisterMessage(FindOrCreateImageRequest)

FindOrCreateImageResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEIMAGERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateImageResponse)
  })
_sym_db.RegisterMessage(FindOrCreateImageResponse)

GetImageRequest = _reflection.GeneratedProtocolMessageType('GetImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:GetImageRequest)
  })
_sym_db.RegisterMessage(GetImageRequest)

ImageObjectResponse = _reflection.GeneratedProtocolMessageType('ImageObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEOBJECTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:ImageObjectResponse)
  })
_sym_db.RegisterMessage(ImageObjectResponse)

ImageBytes = _reflection.GeneratedProtocolMessageType('ImageBytes', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEBYTES,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:ImageBytes)
  })
_sym_db.RegisterMessage(ImageBytes)



_IMAGEAPI = _descriptor.ServiceDescriptor(
  name='ImageApi',
  full_name='ImageApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=455,
  serialized_end=644,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateImage',
    full_name='ImageApi.FindOrCreateImage',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEIMAGEREQUEST,
    output_type=_FINDORCREATEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImage',
    full_name='ImageApi.GetImage',
    index=1,
    containing_service=None,
    input_type=_GETIMAGEREQUEST,
    output_type=_IMAGEOBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageStream',
    full_name='ImageApi.GetImageStream',
    index=2,
    containing_service=None,
    input_type=_GETIMAGEREQUEST,
    output_type=_IMAGEBYTES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGEAPI)

DESCRIPTOR.services_by_name['ImageApi'] = _IMAGEAPI

# @@protoc_insertion_point(module_scope)
